@@ -3,7 +3,7 @@ package App::wordlist;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-09'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.275'; # VERSION
+our $VERSION = '0.276'; # VERSION
 
 use 5.010001;
 use strict;
@@ -349,7 +349,11 @@ sub wordlist {
             my $wl = $wordlists->[$i_wordlist];
             unless ($wl_obj) {
                 log_trace "Instantiating wordlist $wl ...";
-                $wl_obj = WordListUtil::CLI::instantiate_wordlist($wl, 'ignore');
+                eval {
+                    $wl_obj = Module::Load::Util::instantiate_class_with_optional_args(
+                        {ns_prefix=>"WordList"}, $wl);
+                };
+                warn if $@;
                 unless ($wl_obj) {
                     $i_wordlist++;
                     goto REDO;
@@ -495,7 +499,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.275 of App::wordlist (from Perl distribution App-wordlist), released on 2020-06-09.
+This document describes version 0.276 of App::wordlist (from Perl distribution App-wordlist), released on 2020-06-09.
 
 =head1 SYNOPSIS
 
